<?php
/**
 * Arfooo
 * 
 * @package    Arfooo
 * @copyright  Copyright (c) Arfooo Annuaire (fr) and Arfooo Directory (en)
 *             by Guillaume Hocine (c) 2007 - 2010
 *             http://www.arfooo.com/ (fr) and http://www.arfooo.net/ (en)
 * @author     Guillaume Hocine & Adrian Galewski
 * @license    http://creativecommons.org/licenses/by/2.0/fr/ Creative Commons
 */


class RssController extends AppController
{
    /**
     * Add sites items to site rss xml object
     */
    function appendSites($channelNode, $sites)
    {
        foreach ($sites as $siteRecord) {
            $site = $siteRecord->toArray();
            $siteId = $site['siteId'];
            $rawSiteTitle = $site['siteTitle'];

            // Site's permanent link
            $sitePermaLink = AppRouter::getObjectUrl($site, "siteDetails", true);
            unset($site['categoryParents']);

            $site = array_map("utf8_htmlspecialchars", $site); //must be two times for xml and for injections
            $site = array_map("utf8_htmlspecialchars", $site);

            $encodedSiteTitle = NameTool::strToAscii($rawSiteTitle);

            $item = new XmlElement("item");
            $channelNode->appendChild($item);

            $item->addProperty('title', htmlspecialchars($rawSiteTitle));
            $item->addProperty('link', $sitePermaLink);
            $item->addProperty('description', utf8_substr($site['description'], 0, 75));

            // from mysql - YYYY-MM-DD
            $pubDate = $site['creationDate'];
            $year = substr($pubDate, 0, 4);
            $month = substr($pubDate, 5, 2);
            $day = substr($pubDate, 8, 2);

            // must be for RSS in format: Wed, 15 Aug 2007 08:15:32 +0300
            $pubDate = date('D, j M Y H:i:s O', mktime(0, 0, 0, $month, $day, $year));
            $item->addProperty('pubDate', $pubDate);

            $item->addProperty('guid', $sitePermaLink);

        }
    }

    /**
     * Generate news RSS
     */
    function newsAction()
    {
        if (!Config::get("rssNewsEnabled")) {
            $this->return404();
        }
        $doc = new XmlGenerator();

        $rssNode = $doc->createElement('rss');
        $doc->appendChild($rssNode);

        $rssNode->setAttribute('version', '2.0');

        $channelNode = new XmlElement('channel');
        $rssNode->appendChild($channelNode);

        // add channel properties  //new DOMElement('
        $channelNode->addProperty('title', _t('News'));
        $channelNode->addProperty('link', Config::get('siteRootUrl') . AppRouter::getRewrittedUrl('/site/news', false));
        $channelNode->addProperty('description', _t('The new sites'));
        $channelNode->addProperty('language', 'fr-fr');
        $channelNode->addProperty('lastBuildDate', date('D, j M Y H:i:s O'));
        $channelNode->addProperty('generator', 'RSS Generator');

        $sites = $this->siteList->getNewValidatedSites();
        $this->appendSites($channelNode, $sites);

        $this->set("doc", $doc);
        $this->viewClass = "XmlView";
    }

    /**
     * Generate RSS for specified category
     */
    function categoryAction($categoryId)
    {
        if (!Config::get("rssCategoriesEnabled")) {
            $this->return404();
        }

        //get category data
        $category = $this->category->findByPk($categoryId);
        if (empty($category)) {
            return $this->return404();
        }

        $category = $category->toArray();
        $rawCategoryName = $category['name'];

        $doc = new XmlGenerator();

        $rssNode = $doc->createElement('rss');
        $doc->appendChild($rssNode);

        $rssNode->setAttribute('version', '2.0');

        $channelNode = new XmlElement('channel');
        $rssNode->appendChild($channelNode);

        //add channel properties
        $channelNode->addProperty('title', htmlspecialchars($rawCategoryName));
        $channelNode->addProperty('link', AppRouter::getObjectUrl($category, "category", true));

        $channelNode->addProperty('description', _t('Category') . ' ' . htmlspecialchars($rawCategoryName));
        $channelNode->addProperty('language', 'fr-fr');
        $channelNode->addProperty('lastBuildDate', date('D, j M Y H:i:s O'));
        $channelNode->addProperty('generator', 'RSS Generator');

        //retrieve validated sites in this category
        $sites = $this->siteList->getValidatedSitesInCategory($categoryId);
        $this->appendSites($channelNode, $sites);

        $this->set("doc", $doc);
        $this->viewClass = "XmlView";
    }

    /**
     * Generate RSS for specified site
     */
    function siteAction($siteId)
    {
        if (!Config::get("rssSitesEnabled")) {
            $this->return404();
        }

        //get category data
        $site = $this->site->findByPk($siteId);
        if (empty($site)) {
            return $this->return404();
        }

        $this->site->attachParents($site);
        $rawSiteTitle = $site['siteTitle'];

        $doc = new XmlGenerator();

        $rssNode = $doc->createElement('rss');
        $doc->appendChild($rssNode);

        $rssNode->setAttribute('version', '2.0');

        $channelNode = new XmlElement('channel');
        $rssNode->appendChild($channelNode);

        //add channel properties
        $channelNode->addProperty('title', htmlspecialchars($rawSiteTitle));
        $channelNode->addProperty('link', AppRouter::getObjectUrl($site, "siteDetails", true));

        $channelNode->addProperty('description', _t('Site') . ' ' . htmlspecialchars($rawSiteTitle));
        $channelNode->addProperty('language', 'fr-fr');
        $channelNode->addProperty('lastBuildDate', date('D, j M Y H:i:s O'));
        $channelNode->addProperty('generator', 'RSS Generator');

        $sites = array($site);
        $this->appendSites($channelNode, $sites);

        $this->set("doc", $doc);
        $this->viewClass = "XmlView";
    }
}
