<?php
/**
 * Arfooo
 * 
 * @package    Arfooo
 * @copyright  Copyright (c) Arfooo Annuaire (fr) and Arfooo Directory (en)
 *             by Guillaume Hocine (c) 2007 - 2010
 *             http://www.arfooo.com/ (fr) and http://www.arfooo.net/ (en)
 * @author     Guillaume Hocine & Adrian Galewski
 * @license    http://creativecommons.org/licenses/by/2.0/fr/ Creative Commons
 */


class UserController extends AppController
{
    private $editMode = false;

    /**
     * Initailize controller set access privileges
     */
    function init()
    {
        $this->acl->allow('webmaster', $this->name, "*");
        $this->acl->allow('guest', $this->name, "savePhoto");
        $this->acl->allow('guest', $this->name, "deletePhoto");

        if (!$this->acl->isAllowed($this->session->get("role"), $this->name, $this->action)) {
            $this->redirect($this->moduleLink("logIn"));
        }
    }

    function deletePhotoAction()
    {
        $this->viewClass = "JsonView";
        $c = new Criteria();
        $c->add("photoId", $this->request->photoId);

        $photo = $this->photo->find($c);

        if (!empty($photo)) {
            $allow = ($this->session->get("role") == "administrator");

            if (!$allow) {
                if ($photo->itemId) {
                    $item = $this->site->findByPk($photo->itemId);
                    $allow = (!empty($item) && $item->userId == $this->userId);
                } else {
                    $allow = (!empty($this->request->tempId) && $this->request->tempId == $photo->tempId);
                }
            }

            if ($allow) {
                $photo->del();
            }
        }
    }

    function savePhotoAction()
    {
        $this->viewClass = "JsonView";

        $photoType = "gallery";
        $galleryPhotosMaxCount = Config::get("itemGalleryImagesMaxCount");
        $itemId = !empty($this->request->itemId) ? $this->request->itemId : 0;
        $tempId = !empty($this->request->tempId) ? $this->request->tempId : 0;

        if ($itemId) {
            $item = $this->site->findByPk($itemId);

            if (empty($item) || ($this->session->get("role") != "administrator" && $item->webmasterId != $this->userId)) {
                $this->return404();
            }
        }

        try {
            $uploadedFile = new UploadedFile("photo");
            $uploadedFile->addFilter("extension", array("jpg", "jpeg", "gif", "png"));
            $uploadedFile->addFilter("maxSize", intval(Config::get("itemGalleryImageMaxWeight")) * 1024);

            $errorMessage = "";
            $wasUploaded = false;

            if (!$uploadedFile->wasUploaded()) {
                throw new Exception("Photo wasn't uploaded");
            }

            $uploadedFile->validate();

            $savePath = Config::get("SITES_THUMBS_PATH");
            $uploadedFile->setSavePath($savePath);
            $uploadedFile->setAutoCreateDirs(true);
            $uploadedFile->save();
            $savePath = $uploadedFile->getSavePath();

            $fileName = $uploadedFile->getSavedFileName();

            $imageResizer = new ImageResizer();

            if ($photoType == "gallery") {
                if ($this->photo->getSitePhotosCount($itemId, $tempId) >= $galleryPhotosMaxCount) {
                    throw new Exception("Maximum photo count $galleryPhotosMaxCount was reached");
                }

                $photo = new PhotoRecord();
                $photo->itemId = $itemId;

                if ($tempId) {
                    $photo->tempId = $tempId;
                }

                $imageResizer->resize($savePath . $fileName, $savePath . "m" . $fileName, Config::get("mediumThumbWidth"), Config::get("mediumThumbHeight"), true, true);
                $imageResizer->resize($savePath . $fileName, $savePath . "s" . $fileName, Config::get("smallThumbWidth"), Config::get("smallThumbHeight"), true);
                $imageResizer->resize($savePath . $fileName, $savePath . "n" . $fileName, Config::get("microThumbWidth"), Config::get("microThumbHeight"), true, true);

                if (Config::get("imageWatermarkEnabled")) {
                    $imageResizer->addTag($savePath . $fileName, $savePath . $fileName);
                }

                $photo->src = $fileName;
                $photo->save();
            }

            $this->set("status", "ok");
            $this->set("photo", array("thumbSrc" => Config::get("siteRootUrl") . str_replace(CODE_ROOT_DIR, "", $savePath) . "s" . $fileName,
                                      "photoId"  => $photo->photoId,
                                      "name"     => $uploadedFile->getOriginalName()));
        } catch (Exception $e) {
            $this->set("status", "error");
            $this->set("errorMessage", $e->getMessage());
        }
    }
}
